noscript

Macro noscript 

noscript!() { /* proc-macro */ }
<noscript> element.

The <noscript> HTML element defines a section of HTML to be inserted if a script type on the page is unsupported or if scripting is currently turned off in the browser.